@@ -19,6 +19,10 @@ mon_index = 0
 #mon_hp = StringVar()
 hp = StringVar()
 ep = StringVar()
+monstername = StringVar()
+monsterattack = StringVar()
+monsterdefense = StringVar()
+
 
 help_text = StringVar()
 return_from_dialog = StringVar()
@@ -39,11 +43,6 @@ cur_button = 0
 #Used to reduce line length.
 monster_list = []
 
-#Current monster. Used to display stuff like description.
-#Use with monster_list[cur_monster]
-#Note that this is temporary, used to help the move to multi-monster.
-cur_monster = 0
-
 #Number of times you've tried to run from this monster.
 #Used to allow better chances after a while.
 run_attempts = 0
@@ -182,6 +181,7 @@ def choose_monster_prev(event=None):
 			active_button = -1
 			return -1
 	help_text.set("Attack the " + monster_list[active_button].name)
+	set_description_text(active_button)
 	refresh()
 
 def choose_monster_next(event=None):
@@ -199,6 +199,7 @@ def choose_monster_next(event=None):
 			active_button = -1
 			return -1
 	help_text.set("Attack the " + monster_list[active_button].name)
+	set_description_text(active_button)
 	refresh()
 
 #called on Return when the yesno dialog box is active.
@@ -226,6 +227,7 @@ def monster_mouse_move(event=None):
 				event.y <= base_mon_hp_y_start[i]:
 					active_button = i
 					help_text.set("Attack the " + monster_list[i].name)
+					set_description_text(i)
 					refresh()
 	except AttributeError:
 		active_button = -1
@@ -292,11 +294,11 @@ def monster_slashed(i):
 				anchor=CENTER, image=g.buttons["slash_attack.png"], tags="hit"+str(i))
 		else:
 			canvas_mon_pic.create_image(
-				base_mon_hp_start[active_button]+base_mon_hp_width[active_button]/2,
-				base_mon_hp_y_start[active_button]-10,
+				base_mon_hp_start[i]+base_mon_hp_width[i]/2,
+				base_mon_hp_y_start[i]-10,
 				anchor=S, image=g.buttons["slash_attack.png"], tags="hit"+str(i))
 
-#clears slashmark for monster i
+#clears slashmarks for all monsters, and the hero.
 def clear_slashes():
 	for i in range(len(monster_list)):
 		canvas_mon_pic.delete(canvas_mon_pic.find_withtag("hit"+str(i)))
@@ -304,6 +306,7 @@ def clear_slashes():
 
 #use to reward the player for killing a monster
 def monster_dead(i):
+	global active_button
 	#make the display look better
 	monster_list[i].hp = 0
 	#add info to listbox_move; add gold and xp
@@ -319,14 +322,8 @@ def monster_dead(i):
 		main.print_message("and get " + str(exp) + " experience.")
 		g.add_exp(exp)
 	else:
-		j=0
-		while j < len(monster_list[i].on_death):
-			temp = action.activate_line(g.xgrid, g.ygrid, g.zgrid,
-				monster_list[i].on_death[j])
-			if temp == "end": break
-			if main.dead_yet() == 1:
-				break
-			j += 1
+		action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
+					monster_list[i].on_death)
 
 	#finish up
 	if can_leave() == 1:
@@ -335,6 +332,10 @@ def monster_dead(i):
 		global did_run
 		did_run = 0
 	else:
+		for i in range(len(monster_list)):
+			if monster_list[i].hp > 0:
+				active_button = i
+				break
 		refresh()
 
 #returns 1 if battle is finished, (one of the parties is dead) or 0 if not.
@@ -532,8 +533,7 @@ def refresh_buttons():
 	if (cur_button == 0):
 		canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=g.buttons["attack_sel.png"])
-#FIX for multimonster
-		help_text.set("Attack the " + monster_list[cur_monster].name)
+		help_text.set("Attack the " + monster_list[cur_button].name)
 	else: canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=g.buttons["attack.png"])
 	if (cur_button == 1):
@@ -823,6 +823,18 @@ def activate_yesno(event=None):
 	return_from_dialog.set("1")
 
 
+#Sets the description to the left of the battle view to that of
+#the i'th monster
+def set_description_text(i):
+	canvas_desc.delete(ALL)
+	canvas_desc.create_text(1, 5, anchor=NW,
+			text=monster_list[i].description, width=195)
+	monstername.set(monster_list[i].name)
+	monsterattack.set("Attack: " +
+	str(monster_list[i].attack))
+	monsterdefense.set("Defense: " +
+	str(monster_list[i].defense))
+
 #start a battle.
 def begin(mon_index_input):
 
@@ -845,8 +857,6 @@ def begin(mon_index_input):
 	did_run = 0
 	global cur_button
 	cur_button = 0
-	global cur_monster
-	cur_monster = 0
 	global run_attempts
 	run_attempts = 0
 	global active_button
@@ -859,8 +869,6 @@ def begin(mon_index_input):
 	canvas_desc = Canvas(window_battle, width=200, height=190,
 		highlightthickness=0, bg=bgcolour)
 	canvas_desc.grid(row=2, column=1, sticky=NSEW)
-	canvas_desc.create_text(1, 5, anchor=NW,
-			text=monster_list[cur_monster].description, width=195)
 
 	pic_frame = Frame(window_battle, bd=2, relief=SUNKEN, bg="#327a22")
 	pic_frame.grid(row=1, column=2, columnspan=3, rowspan=6, sticky=E)
@@ -921,20 +929,16 @@ def begin(mon_index_input):
 				anchor=N, image=hero_pic, tags="hero")
 
 
-#FIX for multimonster
 	#formatting for the labels.
 	label_formatting = Label(window_battle,
-			text=monster_list[cur_monster].name, bg=bgcolour).grid(row=1,
+			textvariable=monstername, bg=bgcolour).grid(row=1,
 			column=1, columnspan=2)
 
 
-#FIX for multimonster
-	label_attack = Label(window_battle, text="Attack: " +
-	str(monster_list[cur_monster].attack), bg=bgcolour).grid(row=4,
-			column=1, sticky=W)
-	label_defend = Label(window_battle, text="Defense: " +
-	str(monster_list[cur_monster].defense), bg=bgcolour).grid(row=4,
-			column=1, sticky=E)
+	label_attack = Label(window_battle, textvariable=monsterattack,
+			 bg=bgcolour).grid(row=4, column=1, sticky=W)
+	label_defend = Label(window_battle, textvariable=monsterdefense,
+			bg=bgcolour).grid(row=4, column=1, sticky=E)
 
 	#help text
 	label_text = Label(window_battle,
@@ -994,6 +998,7 @@ def begin(mon_index_input):
 	bind_keys()
 
 	main.print_message(monster.monster_groups[mon_index].attack_message)
+	set_description_text(0)
 
 	refresh()
 	refresh_buttons()
