@@ -5,7 +5,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.42. Released under the GPL. Copyright 2005
+#Dragon Hunt 3.44. Released under the GPL. Copyright 2005
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -449,8 +449,7 @@ def add_exp(input_exp):
 	if int(exp) >= int(10*(level + 1)*(level + 1)):
 		level=level+1
 		main.print_message("You gain a level.")
-		for i in levelup_act:
-			action.activate_line(xgrid, ygrid, zgrid, i)
+		action.activate_lines(xgrid, ygrid, zgrid, levelup_act)
 
 
 
@@ -561,6 +560,7 @@ def read_script_file(file_name):
 		#allow the \ line-continuation character.
 		while file_line[-1:] == "\\":  #really a single backslash, BTW.
 			file_line = file_line[:-1] + file.readline()[:-1]
+			file_line = file_line.strip()
 
 		temp_array.append(file_line)
 
