@@ -142,8 +142,8 @@ def inv_show_yesno(line=""):
 	global return_from_yesno
 	return_from_yesno.set("0")
 
-	canvas_width = no_button.width()*4/3+yes_button.width()*4/3
-	canvas_height = yes_button.height()+50
+	canvas_width = g.buttons["no.png"].width()*4/3+g.buttons["yes.png"].width()*4/3
+	canvas_height = g.buttons["yes.png"].height()+50
 	global canvas_inv2
 	canvas_inv2 = Canvas(window_inv, width=canvas_width,
 		height=canvas_height, highlightthickness=0)
@@ -157,9 +157,9 @@ def inv_show_yesno(line=""):
 		width=canvas_width-6, tags="dialogtxt")
 	#buttons
 	canvas_inv2.create_image(canvas_width/2,
-		canvas_height, image=no_button_sel, anchor="se", tags="no")
+		canvas_height, image=g.buttons["no_sel.png"], anchor="se", tags="no")
 	canvas_inv2.create_image(canvas_width/2,
-		canvas_height, image=yes_button, anchor="sw", tags="yes")
+		canvas_height, image=g.buttons["yes.png"], anchor="sw", tags="yes")
 	#bindings
 	main.window_main.bind(g.binding_up, change_yesno_sel)
 	main.window_main.bind(g.binding_right, change_yesno_sel)
@@ -186,15 +186,15 @@ def inv_show_yesno(line=""):
 def change_yesno_to_yes(event=None):
 	global active_button
 	active_button = 1
-	canvas_inv2.itemconfigure("no", image=no_button)
-	canvas_inv2.itemconfigure("yes", image=yes_button_sel)
+	canvas_inv2.itemconfigure("no", image=g.buttons["no.png"])
+	canvas_inv2.itemconfigure("yes", image=g.buttons["yes_sel.png"])
 
 #when a yesno dialog box is active, switch to no.
 def change_yesno_to_no(event=None):
 	global active_button
 	active_button = 0
-	canvas_inv2.itemconfigure("no", image=no_button_sel)
-	canvas_inv2.itemconfigure("yes", image=yes_button)
+	canvas_inv2.itemconfigure("no", image=g.buttons["no_sel.png"])
+	canvas_inv2.itemconfigure("yes", image=g.buttons["yes.png"])
 
 #when a yesno dialog box is active, switch the yes and no buttons.
 def change_yesno_sel(event=None):
@@ -243,10 +243,10 @@ def refresh_buttons(event=0):
 	if curr_item >= len(item.inv) or item.inv[curr_item] == -1:
 		no_item = 1
 	if (cur_button == 0):
-		canvas_buttons.create_image(0, 0, anchor=NW, image=drop_button_sel)
+		canvas_buttons.create_image(0, 0, anchor=NW, image=g.buttons["drop_sel.png"])
 		if no_item == 1: help_text.set("")
 		else: help_text.set("Drop your " + item.item[item.inv[curr_item]].name)
-	else: canvas_buttons.create_image(0, 0, anchor=NW, image=drop_button)
+	else: canvas_buttons.create_image(0, 0, anchor=NW, image=g.buttons["drop.png"])
 	if (cur_button == 1):
 		#switch between equip and use, based on the current item.
 		try:
@@ -256,12 +256,12 @@ def refresh_buttons(event=0):
 
 		if (item_loc <= 6):
 			canvas_buttons.create_image(use_height, 0, anchor=NW,
-					image=equip_button_sel)
+					image=g.buttons["equip_sel.png"])
 			if no_item == 1: help_text.set("")
 			else: help_text.set("Equip your " + item.item[item.inv[curr_item]].name)
 		else:
 			canvas_buttons.create_image(use_height, 0, anchor=NW,
-					image=use_button_sel)
+					image=g.buttons["use_sel.png"])
 			if no_item == 1: help_text.set("")
 			else: help_text.set("Use your " + item.item[item.inv[curr_item]].name)
 	else:
@@ -271,27 +271,27 @@ def refresh_buttons(event=0):
 		except IndexError: item_loc = 50
 
 		if (item_loc <= 6): canvas_buttons.create_image(use_height, 0,
-					anchor=NW, image=equip_button)
+					anchor=NW, image=g.buttons["equip.png"])
 		else: canvas_buttons.create_image(use_height, 0, anchor=NW,
-					image=use_button)
+					image=g.buttons["use.png"])
 	if (cur_button == 2):
 		canvas_buttons.create_image(save_height, 0,
-					anchor=NW, image=save_button_sel)
+					anchor=NW, image=g.buttons["save_sel.png"])
 		help_text.set("Save game")
 	else: canvas_buttons.create_image(save_height, 0, anchor=NW,
-							image=save_button)
+							image=g.buttons["save.png"])
 	if (cur_button == 3):
 		canvas_buttons.create_image(remove_height, 0,
-					anchor=NW, image=remove_button_sel)
+					anchor=NW, image=g.buttons["remove_sel.png"])
 		help_text.set("Remove equipment")
 	else: canvas_buttons.create_image(remove_height, 0, anchor=NW,
-							image=remove_button)
+							image=g.buttons["remove.png"])
 	if (cur_button == 4):
 		canvas_buttons.create_image(leave_height, 0,
-					anchor=NW, image=leave_button_sel)
+					anchor=NW, image=g.buttons["leave_sel.png"])
 		help_text.set("Leave inventory")
 	else: canvas_buttons.create_image(leave_height, 0, anchor=NW,
-							image=leave_button)
+							image=g.buttons["leave.png"])
 
 #refresh this screen. Call after moving around items.
 def refresh_inv():
@@ -579,65 +579,17 @@ def init_window_inv():
 	listbox_equip.grid(row=2, column=2, rowspan=10, sticky=N+W+E)
 
 
-	#Button pictures, both selected and normal.
-	global drop_button; global drop_button_sel
-	global wear_button; global wear_button_sel
-	global use_button; global use_button_sel
-	global equip_button; global equip_button_sel
-	global save_button; global save_button_sel
-	global remove_button; global remove_button_sel
-	global leave_button; global leave_button_sel
-	global yes_button; global yes_button_sel
-	global no_button; global no_button_sel
-
-	drop_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/drop.png")
-	wear_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/equip.png")
-	use_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/use.png")
-	equip_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/equip.png")
-	save_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/save.png")
-	remove_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/remove.png")
-	leave_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/leave.png")
-	yes_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/yes.png")
-	no_button = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/no.png")
-
-	drop_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/drop_sel.png")
-	wear_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/equip_sel.png")
-	use_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/use_sel.png")
-	equip_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/equip_sel.png")
-	save_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/save_sel.png")
-	remove_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/remove_sel.png")
-	leave_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/leave_sel.png")
-	yes_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/yes_sel.png")
-	no_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
-		"/images/buttons/no_sel.png")
-
-	#location of the various buttons.
-	global use_height; use_height = drop_button.width()
-	global save_height; save_height = use_height + use_button.width()
-	global remove_height; remove_height = save_height + save_button.width()
-	global leave_height; leave_height = remove_height + remove_button.width()
+	#Location of the various buttons. Note that these are *_height, but
+	#really measure width. Fix.
+	global use_height; use_height = g.buttons["drop.png"].width()
+	global save_height; save_height = use_height + g.buttons["use.png"].width()
+	global remove_height; remove_height = save_height + g.buttons["save.png"].width()
+	global leave_height; leave_height = remove_height + g.buttons["remove.png"].width()
 
 	#Button canvas.
 	global canvas_buttons
-	canvas_buttons = Canvas(window_inv, height=leave_button_sel.height(),
-		width=leave_height+leave_button.width(), bg=bgcolour)
+	canvas_buttons = Canvas(window_inv, height=g.buttons["leave.png"].height(),
+		width=leave_height+g.buttons["leave.png"].width(), bg=bgcolour)
 	canvas_buttons.grid(column=1, row=13, columnspan=2)
 
 
