@@ -134,16 +134,10 @@ def activate_scripting(x, y, z):
 	#if there are no actions, leave immediately
 	if len(g.maps[temp_zgrid].field[y][x].actions) == 0: return
 
-	i = 0
 	#go through all action lines.
-	while i < len(g.maps[temp_zgrid].field[y][x].actions):
-		temp = action.activate_line(x, y, z,
-			g.maps[temp_zgrid].field[y][x].actions[i])
-		if temp == "end": break
-		if dead_yet() == 1:
-			break
-		i += 1
-	return return_num
+	action.activate_lines(x, y, temp_zgrid,
+					g.maps[temp_zgrid].field[y][x].actions)
+
 
 #redraws the main map. Call after moving.
 def refreshmap():
@@ -176,14 +170,9 @@ def refreshhero():
 def process_onload():
 	for y in range(len(g.maps[g.zgrid].field)):
 		for x in range(len(g.maps[g.zgrid].field[y])):
-			return_num = 0
-			i = 0
-			#go through all action lines.
-			for i in range(len(g.maps[g.zgrid].field[y][x].onload)):
-				temp = action.activate_line(x, y, g.zgrid,
-					g.maps[g.zgrid].field[y][x].onload[i])
-				if temp == "end": break
-				if dead_yet() == 1: break
+			action.activate_lines(x, y, g.zgrid,
+							g.maps[g.zgrid].field[y][x].onload)
+			if dead_yet() == 1: break
 
 #recalculate and display stats. leave_att_def_alone is for calling from a
 #battle, with the possibility of temp bonuses to attack/defense.
@@ -354,14 +343,9 @@ def passturn():
 	g.timestep = g.timestep + 1
 	if g.timestep >= 30: g.timestep = g.timestep - 30
 
-	for line in g.per_turn_script[g.timestep]:
-		return_num = 0
-		i = 0
-		#go through all action lines.
-		temp = action.activate_line(g.xgrid, g.ygrid, g.zgrid,
-				line)
-		if temp == "end": break
-		if dead_yet() == 1: break
+	action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
+		g.per_turn_script[g.timestep])
+	if dead_yet() == 1: return
 
 	#is there a monster here?
 	chance = random() * 100
@@ -653,8 +637,7 @@ def init_window_main(new_game = 0):
 
 	#call newgame script
 	if new_game == 1:
-		for line in g.newgame_act:
-			action.activate_line(g.xgrid, g.ygrid, g.zgrid, line)
+		action.activate_lines(g.xgrid, g.ygrid, g.zgrid, g.newgame_act)
 	g.allow_move = 1
 	action.has_dialog = 0
 
