@@ -299,15 +299,20 @@ def add_item(x, y, name):
 	item = name.split("/", 1)[1]
 	item = item[0:len(item)-4]
 	item_name = re.sub("_", " ", item)
-	var_name = item + "_found" + str(item_list[name])
+	var_name = item + "_" + map_name + "_" + str(item_list[name])
 	item_list[name] += 1
-	cur_map.field[y][x].onload.append("if var " + var_name + " | end | addpix " + name)
+	cur_map.field[y][x].onload.append("if var " + var_name + " = 0")
+	cur_map.field[y][x].onload.append("	addpix " + name)
+	cur_map.field[y][x].onload.append("endif")
 	global amount
 	amount = "AMOUNT"
 	set_item_amount()
-	cur_map.field[y][x].actions.append("if var " + var_name + "| end | pass")
-	cur_map.field[y][x].actions.append("if find \""  + item_name + "\" " + amount + " | set " + var_name + " = 1 | end")
-	cur_map.field[y][x].actions.append("delpix " + name)
+	cur_map.field[y][x].actions.append("if var " + var_name + " = 0")
+	cur_map.field[y][x].actions.append("	if find \""  + item_name + "\" " + amount)
+	cur_map.field[y][x].actions.append("		set " + var_name + " 1")
+	cur_map.field[y][x].actions.append("		delpix " + name)
+	cur_map.field[y][x].actions.append("	endif")
+	cur_map.field[y][x].actions.append("endif")
 
 def set_item_amount():
 	temp_amount = StringVar()
