@@ -9,9 +9,16 @@ from os import listdir
 
 import g
 
+#This class contains one or more monster, that can attack the player in a group.
 class monster_group_class:
 	def __init__(self, name):
 		self.name = str(name)
+		#The message given when the monster group attacks.
+		self.attack_message = "The " + self.name + " attacks you."
+		#The xy coords. of the upper-middle of each monster.
+		self.x_pos = []
+		self.y_pos = []
+		#filled with strings matched up to names in monster_class upon attack.
 		self.monster_list = []
 
 class monster_class:
@@ -25,7 +32,8 @@ class monster_class:
 		self.gold = int(gold)
 		self.description = str(descript)
 		#An array of lines, describing the scripting run when the monster dies.
-		#If given, this replaces the exp/gold giving code.
+		#If given, this *replaces* the exp/gold giving code, making those
+		#entries useless.
 		self.on_death = []
 	def reset(self):  #resets the monster for a battle
 		self.hp = self.maxhp
@@ -41,7 +49,7 @@ def monster_name_to_index(name):
 	for i in range(len(monsters)):
 		if name.lower() == monsters[i].name.lower():
 			return i
-	print "monster " + mon_name + " not found in monsters directory."
+	print "monster " + name + " not found in monsters directory."
 	return -1
 
 
@@ -95,9 +103,19 @@ def read_monster():
 		if monster_line[:1] == ":":
 			monster_groups.append(monster_group_class(monster_line[1:]))
 			cur_group += 1
-		else:
-			monster_groups[cur_group].monster_list.append(monster_line)
-
+			continue
+		monster_command = monster_line.split("=")[0].strip().lower()
+		monster_command2 = monster_line.split("=", 1)[1].strip()
+		if monster_command == "monster":
+			monster_groups[cur_group].monster_list.append(monster_command2)
+		elif monster_command == "attack":
+			monster_groups[cur_group].attack_message = monster_command2
+		elif monster_command == "x_pos":
+			for entry in monster_command2.split(","):
+				monster_groups[cur_group].x_pos.append(int(entry.strip()))
+		elif monster_command == "y_pos":
+			for entry in monster_command2.split(","):
+				monster_groups[cur_group].y_pos.append(int(entry.strip()))
 
 #given a filename, (relative to g.mod_directory + "/data/monsters")
 #open and interpret the monster.
