@@ -167,28 +167,28 @@ def refresh_buttons():
 	canvas_buttons.delete(ALL)
 	if (cur_button == 0):
 		canvas_buttons.create_image(0, 0, anchor=NW,
-							image=begin_button_sel, tags="begin")
+							image=g.buttons["begin_sel.png"], tags="begin")
 		help_text.set("Begin a new game")
 	else: canvas_buttons.create_image(0, 0, anchor=NW,
-							image=begin_button, tags="begin")
+							image=g.buttons["begin.png"], tags="begin")
 	if (cur_button == 1):
 		canvas_buttons.create_image(0, reroll_height, anchor=NW,
-							image=reroll_button_sel, tags="reroll")
+							image=g.buttons["reroll_sel.png"], tags="reroll")
 		help_text.set("Reroll your statistics")
 	else: canvas_buttons.create_image(0, reroll_height, anchor=NW,
-							image=reroll_button, tags="reroll")
+							image=g.buttons["reroll.png"], tags="reroll")
 	if (cur_button == 2):
 		canvas_buttons.create_image(0, load_height, anchor=NW,
-							image=load_button_sel, tags="load")
+							image=g.buttons["load_sel.png"], tags="load")
 		help_text.set("Load an old game")
 	else: canvas_buttons.create_image(0, load_height, anchor=NW,
-							image=load_button, tags="load")
+							image=g.buttons["load.png"], tags="load")
 	if (cur_button == 3):
 		canvas_buttons.create_image(0, quit_height, anchor=NW,
-							image=quit_button_sel, tags="quit")
+							image=g.buttons["quit_sel.png"], tags="quit")
 		help_text.set("Quit this game")
 	else: canvas_buttons.create_image(0, quit_height, anchor=NW,
-							image=quit_button, tags="quit")
+							image=g.buttons["quit.png"], tags="quit")
 
 
 #All keypresses in window_shop pass through here. Based on the key name,
@@ -294,45 +294,21 @@ def init_window():
 		textvariable=gold, bg=bgcolour).grid(row=7, column=3, sticky=W+N)
 
 
-	#Actual buttons, both selected and normal.
-	global begin_button; global begin_button_sel
-	global reroll_button; global reroll_button_sel
-	global load_button; global load_button_sel
-	global quit_button; global quit_button_sel
-
-
-	begin_button = \
-		ImageTk.PhotoImage(file=g.mod_directory + "/images/buttons/begin.png")
-	reroll_button = \
-		ImageTk.PhotoImage(file=g.mod_directory + "/images/buttons/reroll.png")
-	load_button = \
-		ImageTk.PhotoImage(file=g.mod_directory + "/images/buttons/load.png")
-	quit_button = \
-		ImageTk.PhotoImage(file=g.mod_directory + "/images/buttons/quit.png")
-
-	begin_button_sel = ImageTk.PhotoImage(
-		file=g.mod_directory + "/images/buttons/begin_sel.png")
-	reroll_button_sel = ImageTk.PhotoImage(
-		file=g.mod_directory + "/images/buttons/reroll_sel.png")
-	load_button_sel = ImageTk.PhotoImage(
-		file=g.mod_directory + "/images/buttons/load_sel.png")
-	quit_button_sel = ImageTk.PhotoImage(
-		file=g.mod_directory + "/images/buttons/quit_sel.png")
-
-	#Canvas for buttons
-	global canvas_buttons
-	canvas_buttons = Canvas(new_game, width=begin_button.width(), bg="#d3d3d3",
-		height=begin_button.height() + reroll_button.height() +
-		load_button.height() + quit_button.height(), highlightthickness=0)
-	canvas_buttons.grid(column=1, row=1, rowspan=20, sticky=N+W+E)
 
 	#add height values
 	global reroll_height
 	global load_height
 	global quit_height
-	reroll_height = begin_button.height()
-	load_height = reroll_height + reroll_button.height()
-	quit_height = load_height + load_button.height()
+	reroll_height = g.buttons["begin.png"].height()
+	load_height = reroll_height + g.buttons["reroll.png"].height()
+	quit_height = load_height + g.buttons["load.png"].height()
+
+	#Canvas for buttons
+	global canvas_buttons
+	canvas_buttons = Canvas(new_game, width=g.buttons["begin.png"].width(),
+		bg="#d3d3d3", height=quit_height +
+		g.buttons["quit.png"].height(), highlightthickness=0)
+	canvas_buttons.grid(column=1, row=1, rowspan=20, sticky=N+W+E)
 
 	entry_name.focus_set()
 	refresh_buttons()
